@@ -92,7 +92,7 @@ class DbtYamlManager(DbtProject):
 
     # TODO: Let user supply a custom arg / config file / csv of strings which we
     # consider placeholders which are not valid documentation, these are just my own
-    # We may well drop the placeholder concept too
+    # We may well drop the placeholder concept too. It is just a convenience for refactors
     placeholders = [
         "Pending further documentation",
         "Pending further documentation.",
@@ -102,7 +102,7 @@ class DbtYamlManager(DbtProject):
         "Not documented.",
         "Undefined",
         "Undefined.",
-        "",
+        "",  # This is the important one
     ]
 
     def __init__(
@@ -113,17 +113,35 @@ class DbtYamlManager(DbtProject):
         threads: Optional[int] = 1,
         fqn: Optional[str] = None,
         dry_run: bool = False,
+        models: Optional[List[str]] = None,
     ):
+        """Initializes the DbtYamlManager class."""
         super().__init__(  # partial parse messes up our f strings, so force a full parse on init
             target, profiles_dir, project_dir, threads, {"_reparse_seed": os.urandom(8).hex()}
         )
         self.fqn = fqn
+        self.models = models or []
         self.dry_run = dry_run
+
+        if len(list(self.filtered_models())) == 0:
+            logger().warning(
+                "No models found to process. Check your filters: --fqn='%s', pos args %s",
+                fqn,
+                models,
+            )
+            logger().info(
+                "Please supply a valid fqn segment if using --fqn or a valid model name, path, or"
+                " subpath if using positional arguments"
+            )
+            exit(0)
+
         self.mutex = Lock()
         self.tpe = ThreadPoolExecutor(max_workers=os.cpu_count() * 2)
+        self.mutations = 0
 
     @property
     def yaml_handler(self):
+        """Returns a cached instance of the YAML handler."""
         if not hasattr(self, "_yaml_handler"):
             self._yaml_handler = YamlHandler()
         return self._yaml_handler
@@ -134,28 +152,66 @@ class DbtYamlManager(DbtProject):
             return column.upper()
         return column
 
-    def _filter_model(self, node: ManifestNode) -> bool:
-        """Validates a node as being actionable. Validates both models and sources."""
+    def _filter_model_by_fqn(self, node: ManifestNode) -> bool:
+        """Validates a node as being selected.
+
+        Check FQN length
+        Check FQN matches parts
+        """
+        if not self.fqn:
+            return True
         fqn = self.fqn or ".".join(node.fqn[1:])
         fqn_parts = fqn.split(".")
-        logger().debug("%s: %s -> %s", node.resource_type, fqn, node.fqn[1:])
+        return len(node.fqn[1:]) >= len(fqn_parts) and all(
+            left == right for left, right in zip(fqn_parts, node.fqn[1:])
+        )
+
+    def _filter_model_by_models(self, node: ManifestNode) -> bool:
+        """Validates a node as being selected.
+
+        Check if the node name matches a model name
+        Check if the node path matches a model path
+        Check if the node path is a child of a model path
+        """
+        for model in self.models:
+            if node.name == model:
+                return True
+            node_path = self.get_node_path(node)
+            inp_path = as_path(model).resolve()
+            if inp_path.is_dir():
+                if node_path and inp_path in node_path.parents:
+                    return True
+            elif inp_path.is_file():
+                if node_path and inp_path == node_path:
+                    return True
+        return False
+
+    def _filter_model(self, node: ManifestNode) -> bool:
+        """Validates a node as being actionable.
+
+        Check if the node is a model
+        Check if the node is a source
+        Check if the node is a model and not ephemeral
+        Check if the node is a model and matches the fqn or models filter if supplied
+        """
+        if self.models:
+            filter_method = self._filter_model_by_models
+        elif self.fqn:
+            filter_method = self._filter_model_by_fqn
+        else:
+            filter_method = lambda _: True  # noqa: E731
         return (
-            # Verify Resource Type
             node.resource_type in (NodeType.Model, NodeType.Source)
-            # Verify Package == Current Project
             and node.package_name == self.project_name
-            # Verify Materialized is Not Ephemeral if NodeType is Model [via short-circuit]
             and not (
                 node.resource_type == NodeType.Model and node.config.materialized == "ephemeral"
             )
-            # Verify FQN Length [Always true if no fqn was supplied]
-            and len(node.fqn[1:]) >= len(fqn_parts)
-            # Verify FQN Matches Parts [Always true if no fqn was supplied]
-            and all(left == right for left, right in zip(fqn_parts, node.fqn[1:]))
+            and filter_method(node)
         )
 
     @staticmethod
     def get_patch_path(node: ManifestNode) -> Optional[Path]:
+        """Returns the patch path for a node if it exists"""
         if node is not None and node.patch_path:
             return as_path(node.patch_path.split("://")[-1])
 
@@ -192,6 +248,10 @@ class DbtYamlManager(DbtProject):
                 f"Invalid config for model {node.name}: {osmosis_spec}"
             ) from exc
 
+    def get_node_path(self, node: ManifestNode):
+        """Resolve absolute file path for a manifest node"""
+        return as_path(self.config.project_root, node.original_file_path).resolve()
+
     def get_schema_path(self, node: ManifestNode) -> Optional[Path]:
         """Resolve absolute schema file path for a manifest node"""
         schema_path = None
@@ -359,6 +419,7 @@ class DbtYamlManager(DbtProject):
                         },
                         schema_file,
                     )
+                    self.mutations += 1
                 performed_disk_mutation = True
 
         if performed_disk_mutation:
@@ -389,79 +450,88 @@ class DbtYamlManager(DbtProject):
         return schema_map
 
     def _draft(self, schema_file: SchemaFileLocation, unique_id: str, blueprint: dict) -> None:
-        with self.mutex:
-            blueprint.setdefault(
-                schema_file.target,
-                SchemaFileMigration(
-                    output={"version": 2, "models": [], "sources": []}, supersede={}
-                ),
-            )
-        if schema_file.node_type == NodeType.Model:
-            node = self.manifest.nodes[unique_id]
-        elif schema_file.node_type == NodeType.Source:
-            node = self.manifest.sources[unique_id]
-        else:
-            return
-        if schema_file.current is None:
-            # Bootstrapping undocumented NodeType.Model
-            # NodeType.Source files are guaranteed to exist by this point
+        try:
             with self.mutex:
-                assert schema_file.node_type == NodeType.Model
-                blueprint[schema_file.target].output["models"].append(self.get_base_model(node))
-        else:
-            # Sanity check that the file exists before we try to load it, this should never be false
-            assert schema_file.current.exists(), f"File {schema_file.current} does not exist"
-            # Model/Source Is Documented but Must be Migrated
+                blueprint.setdefault(
+                    schema_file.target,
+                    SchemaFileMigration(
+                        output={"version": 2, "models": [], "sources": []}, supersede={}
+                    ),
+                )
+            if schema_file.node_type == NodeType.Model:
+                node = self.manifest.nodes[unique_id]
+            elif schema_file.node_type == NodeType.Source:
+                node = self.manifest.sources[unique_id]
+            else:
+                return
+            if schema_file.current is None:
+                # Bootstrapping undocumented NodeType.Model
+                # NodeType.Source files are guaranteed to exist by this point
+                with self.mutex:
+                    assert schema_file.node_type == NodeType.Model
+                    blueprint[schema_file.target].output["models"].append(self.get_base_model(node))
+            else:
+                # Sanity check that the file exists before we try to load it, this should never be false
+                assert schema_file.current.exists(), f"File {schema_file.current} does not exist"
+                # Model/Source Is Documented but Must be Migrated
+                with self.mutex:
+                    schema = self.yaml_handler.load(schema_file.current)
+                models_in_file: Iterable[Dict[str, Any]] = schema.get("models", [])
+                sources_in_file: Iterable[Dict[str, Any]] = schema.get("sources", [])
+                for documented_model in (
+                    model for model in models_in_file if model["name"] == node.name
+                ):
+                    # Augment Documented Model
+                    augmented_model = self.augment_existing_model(documented_model, node)
+                    with self.mutex:
+                        blueprint[schema_file.target].output["models"].append(augmented_model)
+                        # Target to supersede current
+                        blueprint[schema_file.target].supersede.setdefault(
+                            schema_file.current, []
+                        ).append(node)
+                    break
+                for documented_model, i in (
+                    (table, j)
+                    for j, source in enumerate(sources_in_file)
+                    if source["name"] == node.source_name
+                    for table in source["tables"]
+                    if table["name"] == node.name
+                ):
+                    # Augment Documented Source
+                    augmented_model = self.augment_existing_model(documented_model, node)
+                    with self.mutex:
+                        if not any(
+                            s["name"] == node.source_name
+                            for s in blueprint[schema_file.target].output["sources"]
+                        ):
+                            # Add the source if it doesn't exist in the blueprint
+                            blueprint[schema_file.target].output["sources"].append(
+                                sources_in_file[i]
+                            )
+                        # Find source in blueprint
+                        for src in blueprint[schema_file.target].output["sources"]:
+                            if src["name"] == node.source_name:
+                                # Find table in blueprint
+                                for tbl in src["tables"]:
+                                    if tbl["name"] == node.name:
+                                        # Augment table
+                                        tbl = augmented_model
+                                        break
+                                break
+                        else:
+                            # This should never happen
+                            raise RuntimeError(f"Source {node.source_name} not found in blueprint?")
+                        # Target to supersede current
+                        blueprint[schema_file.target].supersede.setdefault(
+                            schema_file.current, []
+                        ).append(node)
+                    break
+        except Exception as e:
             with self.mutex:
-                schema = self.yaml_handler.load(schema_file.current)
-            models_in_file: Iterable[Dict[str, Any]] = schema.get("models", [])
-            sources_in_file: Iterable[Dict[str, Any]] = schema.get("sources", [])
-            for documented_model in (
-                model for model in models_in_file if model["name"] == node.name
-            ):
-                # Augment Documented Model
-                augmented_model = self.augment_existing_model(documented_model, node)
-                with self.mutex:
-                    blueprint[schema_file.target].output["models"].append(augmented_model)
-                    # Target to supersede current
-                    blueprint[schema_file.target].supersede.setdefault(
-                        schema_file.current, []
-                    ).append(node)
-                break
-            for documented_model, i in (
-                (table, j)
-                for j, source in enumerate(sources_in_file)
-                if source["name"] == node.source_name
-                for table in source["tables"]
-                if table["name"] == node.name
-            ):
-                # Augment Documented Source
-                augmented_model = self.augment_existing_model(documented_model, node)
-                with self.mutex:
-                    if not any(
-                        s["name"] == node.source_name
-                        for s in blueprint[schema_file.target].output["sources"]
-                    ):
-                        # Add the source if it doesn't exist in the blueprint
-                        blueprint[schema_file.target].output["sources"].append(sources_in_file[i])
-                    # Find source in blueprint
-                    for src in blueprint[schema_file.target].output["sources"]:
-                        if src["name"] == node.source_name:
-                            # Find table in blueprint
-                            for tbl in src["tables"]:
-                                if tbl["name"] == node.name:
-                                    # Augment table
-                                    tbl = augmented_model
-                                    break
-                            break
-                    else:
-                        # This should never happen
-                        raise RuntimeError(f"Source {node.source_name} not found in blueprint?")
-                    # Target to supersede current
-                    blueprint[schema_file.target].supersede.setdefault(
-                        schema_file.current, []
-                    ).append(node)
-                break
+                logger().error(
+                    "Failed to draft project structure update plan for %s: %s", unique_id, e
+                )
+            raise e
 
     def draft_project_structure_update_plan(self) -> Dict[Path, SchemaFileMigration]:
         """Build project structure update plan based on `dbt-osmosis:` configs set across
@@ -529,6 +599,7 @@ class DbtYamlManager(DbtProject):
                     target.parent.mkdir(exist_ok=True, parents=True)
                     target.touch()
                     self.yaml_handler.dump(structure.output, target)
+                    self.mutations += 1
 
             else:
                 # Update File
@@ -546,6 +617,7 @@ class DbtYamlManager(DbtProject):
                     target_schema.setdefault("sources", []).extend(structure.output["sources"])
                 if not self.dry_run:
                     self.yaml_handler.dump(target_schema, target)
+                    self.mutations += 1
 
             # Clean superseded schema files
             for dir, nodes in structure.supersede.items():
@@ -599,6 +671,7 @@ class DbtYamlManager(DbtProject):
                             raw_schema["sources"].pop(i)
                     if not self.dry_run:
                         self.yaml_handler.dump(raw_schema, dir)
+                        self.mutations += 1
                     logger().info(
                         ":satellite: Model documentation migrated from %s to %s",
                         dir.name,
@@ -775,7 +848,7 @@ class DbtYamlManager(DbtProject):
                 if section is None:  # If we can't find the section, we can't take action
                     logger().info(":thumbs_up: No actions needed for %s", node.unique_id)
                     return
-            
+
                 should_dump = False
                 n_cols_added, n_cols_doc_inherited, n_cols_removed = 0, 0, 0
                 if len(missing_columns) > 0 or len(undocumented_columns) or len(extra_columns) > 0:
@@ -803,6 +876,7 @@ class DbtYamlManager(DbtProject):
                 if should_dump and not self.dry_run:
                     # Dump the mutated schema file back to the disk
                     self.yaml_handler.dump(schema_file, schema_path.current)
+                    self.mutations += 1
                     logger().info(
                         ":sparkles: Schema file %s updated",
                         schema_path.current,
@@ -838,7 +912,7 @@ class DbtYamlManager(DbtProject):
         except Exception as e:
             with self.mutex:
                 logger().error("Error occurred while processing model %s: %s", unique_id, e)
-                raise e
+            raise e
 
     def propagate_documentation_downstream(self, force_inheritance: bool = False) -> None:
         schema_map = self.build_schema_folder_mapping()
