@@ -6,7 +6,7 @@ import threading
 import time
 from dataclasses import asdict
 from pathlib import Path
-from typing import Callable, Optional, Union
+from typing import Callable, Optional, Union, List
 from urllib.parse import urlencode
 
 import click
@@ -109,6 +109,13 @@ def shared_opts(func: Callable) -> Callable:
     is_flag=True,
     help="If specified, no changes are committed to disk.",
 )
+@click.option(
+    "-C",
+    "--check",
+    is_flag=True,
+    help="If specified, will return a non-zero exit code if any files are changed.",
+)
+@click.argument("models", nargs=-1)
 def refactor(
     target: Optional[str] = None,
     project_dir: Optional[str] = None,
@@ -116,6 +123,8 @@ def refactor(
     fqn: Optional[str] = None,
     force_inheritance: bool = False,
     dry_run: bool = False,
+    check: bool = False,
+    models: Optional[List[str]] = None,
 ):
     """Executes organize which syncs yaml files with database schema and organizes the dbt models
     directory, reparses the project, then executes document passing down inheritable documentation
@@ -137,12 +146,15 @@ def refactor(
         target=target,
         fqn=fqn,
         dry_run=dry_run,
+        models=models,
     )
 
     # Conform project structure & bootstrap undocumented models injecting columns
     if runner.commit_project_restructure_to_disk():
         runner.safe_parse_project(reinit=True)
     runner.propagate_documentation_downstream(force_inheritance=force_inheritance)
+    if check and runner.mutations > 0:
+        exit(1)
 
 
 @yaml.command(context_settings=CONTEXT)
@@ -162,12 +174,21 @@ def refactor(
     is_flag=True,
     help="If specified, no changes are committed to disk.",
 )
+@click.option(
+    "-C",
+    "--check",
+    is_flag=True,
+    help="If specified, will return a non-zero exit code if any files are changed.",
+)
+@click.argument("models", nargs=-1)
 def organize(
     target: Optional[str] = None,
     project_dir: Optional[str] = None,
     profiles_dir: Optional[str] = None,
     fqn: Optional[str] = None,
     dry_run: bool = False,
+    check: bool = False,
+    models: Optional[List[str]] = None,
 ):
     """Organizes schema ymls based on config and injects undocumented models
 
@@ -188,10 +209,13 @@ def organize(
         target=target,
         fqn=fqn,
         dry_run=dry_run,
+        models=models,
     )
 
     # Conform project structure & bootstrap undocumented models injecting columns
     runner.commit_project_restructure_to_disk()
+    if check and runner.mutations > 0:
+        exit(1)
 
 
 @yaml.command(context_settings=CONTEXT)
@@ -220,6 +244,13 @@ def organize(
     is_flag=True,
     help="If specified, no changes are committed to disk.",
 )
+@click.option(
+    "-C",
+    "--check",
+    is_flag=True,
+    help="If specified, will return a non-zero exit code if any files are changed.",
+)
+@click.argument("models", nargs=-1)
 def document(
     target: Optional[str] = None,
     project_dir: Optional[str] = None,
@@ -227,6 +258,8 @@ def document(
     fqn: Optional[str] = None,
     force_inheritance: bool = False,
     dry_run: bool = False,
+    check: bool = False,
+    models: Optional[List[str]] = None,
 ):
     """Column level documentation inheritance for existing models
 
@@ -247,10 +280,13 @@ def document(
         target=target,
         fqn=fqn,
         dry_run=dry_run,
+        models=models,
     )
 
     # Propagate documentation & inject/remove schema file columns to align with model in database
     runner.propagate_documentation_downstream(force_inheritance)
+    if check and runner.mutations > 0:
+        exit(1)
 
 
 class ServerRegisterThread(threading.Thread):
@@ -553,7 +589,7 @@ def workbench(
             "--runner.magicEnabled=false",
             f"--browser.serverAddress={host}",
             f"--browser.serverPort={port}",
-            Path(__file__).parent / "app.py",
+            Path(__file__).parent / "app_v2.py",
         ]
         + ctx.args
         + script_args,
